@@ -91,6 +91,11 @@ replace_type <- function(type, pattern, replacement, case_insensitive) {
     if (!is.character(pattern) || !is.character(replacement))
         stop("'pattern' and 'replacement' must be characters")
     if (!length(type)) return(character())
+    
+    # normalize unicode
+    pattern <- stri_trans_nfc(pattern)
+    replacement <- stri_trans_nfc(replacement)
+    
     if (case_insensitive) {
         type_new <- replacement[match(stri_trans_tolower(type), stri_trans_tolower(pattern))]
     } else {
