@@ -1,5 +1,6 @@
-#include "quanteda.h"
+#include "lib.h"
 using namespace quanteda;
+using namespace arma;
 
 /* 
  * This function removes a string from of a list of string vectors.
