@@ -158,8 +158,11 @@ test_that("test corpus constructors works for data.frame", {
                      metacorpus = list(source = "From a data.frame called mydf."))
     expect_equal(docnames(mycorp), 
                  paste("fromDf", 1:6, sep = "_"))
-    expect_equal(mycorp[["letter_factor"]][3,1],
-                 factor("b", levels = c("a", "b", "c")))
+    suppressWarnings({
+        expect_equal(mycorp[["letter_factor"]][3,1],
+                     factor("b", levels = c("a", "b", "c")))
+    })
+    expect_warning(mycorp[["letter_factor"]])
     
     mydf2 <- mydf
     names(mydf2)[3] <- "text"
