@@ -1,4 +1,4 @@
-context("tests of textmodel_mixfit")
+context("tests of textmodel_affinity")
 
 test_that("textmodel_affinity works as expected",  {
     fitted <- textmodel_affinity(data_dfm_lbgexample, y = c("L", NA, NA, NA, "R", NA))
@@ -21,3 +21,11 @@ test_that("textmodel_affinity works for tolower = TRUE dfm objects (#1338)", {
         "Training documents per class:one: 1, two: 1; total training features: 4"
     )
 })
+
+test_that("raises error when dfm is empty (#1419)",  {
+    
+    mx <- dfm_trim(data_dfm_lbgexample, 1000)
+    expect_error(textmodel_affinity(mx, y = c(-1, NA, NA, NA, 1, NA)),
+                 quanteda:::message_error("dfm_empty"))
+
+})
